#
# spec file for package perl-Plack-Middleware-Session
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Plack-Middleware-Session
Name:           perl-Plack-Middleware-Session
Version:        0.340.0
Release:        1.2
# 0.34 -> normalize -> 0.340.0
%define cpan_version 0.34
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Middleware for session management
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MI/MIYAGAWA/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Cookie::Baker) >= 0.120
BuildRequires:  perl(Digest::HMAC_SHA1) >= 1.03
BuildRequires:  perl(Digest::SHA)
BuildRequires:  perl(HTTP::Cookies)
BuildRequires:  perl(HTTP::Request::Common)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Module::Build)
BuildRequires:  perl(Module::Build::Tiny) >= 0.034
BuildRequires:  perl(Plack) >= 0.9910
BuildRequires:  perl(Test::Fatal) >= 0.006
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Requires)
Requires:       perl(Cookie::Baker) >= 0.120
Requires:       perl(Digest::HMAC_SHA1) >= 1.03
Requires:       perl(Digest::SHA)
Requires:       perl(Plack) >= 0.9910
Provides:       perl(Plack::Middleware::Session) = %{version}
Provides:       perl(Plack::Middleware::Session::Cookie)
Provides:       perl(Plack::Session) = %{version}
Provides:       perl(Plack::Session::Cleanup) = %{version}
Provides:       perl(Plack::Session::State) = %{version}
Provides:       perl(Plack::Session::State::Cookie) = %{version}
Provides:       perl(Plack::Session::Store) = %{version}
Provides:       perl(Plack::Session::Store::Cache) = %{version}
Provides:       perl(Plack::Session::Store::DBI) = %{version}
Provides:       perl(Plack::Session::Store::File) = %{version}
Provides:       perl(Plack::Session::Store::Null) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This is a Plack Middleware component for session management. By default it
will use cookies to keep session state and store data in memory. This
distribution also comes with other state and store solutions. See perldoc
for these backends how to use them.

It should be noted that we store the current session as a hash reference in
the 'psgix.session' key inside the '$env' where you can access it as
needed.

*NOTE:* As of version 0.04 the session is stored in 'psgix.session' instead
of 'plack.session'.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
# put . back into @INC for tests
export PERL5LIB=$PWD
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes examples README
%license LICENSE

%changelog
* Tue Sep 24 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.340.0 (0.34)
  see /usr/share/doc/packages/perl-Plack-Middleware-Session/Changes
  0.34  2024-09-23 09:54:12 PDT
  - Add support for Partitioned cookies (CHIP) #51
* Wed Mar 13 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.33
  see /usr/share/doc/packages/perl-Plack-Middleware-Session/Changes
  0.33  2019-03-09 15:18:15 PST
  - Removed dependency to Digest::SHA1 #45
  - Added explicit dep to HTTP::Request::Common #44
  - Add t/lib to INC for Perl 5.26+
  - Fix POD link
* Wed Feb 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 0.32
  see /usr/share/doc/packages/perl-Plack-Middleware-Session/Changes
  0.32  2019-02-26 14:36:19 MST
  - Fix dependency for Cookie::Baker
  0.31  2019-02-26 12:01:00 MST
  - Documentation fix
  - Support samesite cookie attributes #42
* Wed Oct 18 2017 coolo@suse.com
- make sure . is in @INC while testing
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.30
  see /usr/share/doc/packages/perl-Plack-Middleware-Session/Changes
  0.30  2015-03-02 10:24:38 PST
  - Fix VERSION
  0.29  2015-02-17 15:56:25 PST
  - Moved repo to the plack organization on github
  0.28  2015-02-16 08:30:08 PST
  - Same as 0.27. Make it non-trial
  0.27  2015-02-13 16:52:11 PST
  - Added late_store in psgix.session.options to update the session after the streaming
    and reverts the default behavior to pre-0.26 (reported by darkkar, fixed by alexmv) #29, #30
  0.26  2015-02-03 09:17:38 CET
  - Improved documentation (oalders, basiliscos, Mohammad Anwar, alexmv)
  - Session storage is now updated in the cleanup phase, after the streaming is complete (alexmv) #28
  0.25  2014-09-28 20:07:42 PDT
  - Make tests safer for parallel execution. #21
  0.24  2014-09-05 04:49:59 PDT
  - No changes since 0.23
  0.23  2014-08-11 10:22:40 PDT
  - Changed the warning to error, when secret is not set.
  0.22  2014-08-11 10:16:51 PDT
  - Document the vunlerability of using this middleware without secret, and
    warn when secret is not set on the runtime. In the next release the default
    will be changed to require the secret. (mala)
* Wed Jul 30 2014 ncutler@suse.com
- updated to 0.21
  0.21  2013-10-12 11:41:37 PDT
  - use Cookie::Baker (kazeburo)
* Sat May 24 2014 ncutler@suse.com
- regenerated spec file using cpanspec 1.78.07
- updated to 0.20
  0.20  2013-06-24 16:09:21 PDT
  - Fix packaging (name casing)
  0.19  2013-06-24 15:09:55 PDT
  - Use Milla
  - Add prereqs to LWP/HTTP::Cookies
  0.18 Tue Feb 12 02:56:23 PST 2013
  - Repackaging
  0.17 Mon Feb 11 15:40:50 PST 2013
  - Use constant time comparison of HMAC signature to be precautious for timing attacks
  0.16 Sun Feb 10 11:41:14 PST 2013
  - Fix minimum version requirement for Test::Fatal
  0.15 Tue Sep  4 14:15:13 PDT 2012
  - Fixed CPAN dependencies
* Mon Oct 10 2011 coolo@suse.com
- initial package 0.14
  * created by cpanspec 1.78.06
